@@ -449,7 +449,7 @@ Returns the L<Mojo::IOLoop::ReadWriteProcess> process identified by its pid if b
 =head2 register()
 
     use Mojo::IOLoop::ReadWriteProcess::Session qw(session);
-    my $process = session->register(Mojo::IOLoop::ReadWriteProcess->new);
+    my $process = session->register('pid' => Mojo::IOLoop::ReadWriteProcess->new);
 
 Register the L<Mojo::IOLoop::ReadWriteProcess> process to the session.
 
@@ -463,7 +463,7 @@ Unregister the corresponding L<Mojo::IOLoop::ReadWriteProcess> with the given pi
 =head2 collect()
 
     use Mojo::IOLoop::ReadWriteProcess::Session qw(session);
-    my $process = session->collect(123342, 0, undef);
+    my $process = session->collect(123342 => 0 => undef);
 
 Collect the status for the given pid.
 
